@@ -3,10 +3,16 @@ package B::Module::Info;
 $VERSION = '0.24';
 
 use B;
-use B::Utils qw(walkoptree_filtered walkoptree_simple
-                opgrep all_roots);
+use B::BUtils qw(walkoptree_filtered walkoptree_simple
+                 opgrep all_roots);
 @B::Utils::bad_stashes = qw();  # give us everything.
 
+=head1 NAME
+
+B::Module::Info - information about Perl modules
+
+=cut
+
 {
     # From: Roland Walker <walker@ncbi.nlm.nih.gov>
     # "Syntax OK" may land inside output and render it unusable
@@ -92,7 +98,7 @@ sub roots_cv_pairs {
 
 
 my %modes = (
-             packages => sub { 
+             packages => sub {
                  walkoptree_filtered(B::main_root,
                                      \&state_change,
                                      \&state_call );
